import re
from run import Module, Task
from run.library import RenderTask, ParseVar

class PythonPackgramModule(Module):
        
    #Tasks
    
    render = Task(
        require=['render_setup'],
    )
    
    render_setup = RenderTask(
        source='setup.tpl', 
        target='setup.py',
    )
    
    #Vars
    
    author = ParseVar(
        file_pattern='AUTHORS.rst', 
        text_pattern=r'\n-\s+(.*?)\s+<.*?@.*?>',
        processors=[
            lambda items: items[0],
        ],
    ) 
          
    author_email = ParseVar(
        file_pattern='AUTHORS.rst',
        text_pattern=r'\n-\s+.*?\s+<(.*?@.*?)>',    
        processors=[
            lambda items: items[0],
        ],
    )   
     
    classifiers = ParseVar(
        file_pattern='README.rst',
        text_pattern=r'- ([^\n]* :: [^\n]*)',       
    )
     
    description = ParseVar(
        file_pattern='README.rst',
        text_pattern=r'.*?=\s+(.*?)(?:\n|$)',    
        processors=[
            lambda items: items[0],
        ],
    )
     
    license = ParseVar(
        file_pattern='LICENSE.rst',
        text_pattern=r'(.*?)\s+=',
        processors=[
            lambda items: items[0],
        ],
    )
     
    long_description = ParseVar(
        file_pattern='README.rst',
        text_pattern=r'(.*)',
        text_pattern_flags=re.DOTALL,   
        processors=[
            lambda items: items[0],
        ],
    )    
      
    maintainer = ParseVar(
        file_pattern='AUTHORS.rst',
        text_pattern=r'\n-\s+(.*?)\s+<.*?@.*?>',  
        processors=[
            lambda items: items[0],
        ],
    ) 
        
    maintainer_email = ParseVar(
        file_pattern='AUTHORS.rst',
        text_pattern=r'\n-\s+.*?\s+<(.*?@.*?)>',   
        processors=[
            lambda items: items[0],
        ],
    )
        
    name = ParseVar(
        file_pattern='README.rst',
        text_pattern=r'(.*?)\s+=',
        processors=[
            lambda items: items[0],
            str.lower,
        ],
    )
     
    version = ParseVar(
        file_pattern='.*version.py',
        text_pattern=r'(?:major|minor|micro|level)\s*=\s*[\'"]?(\w*)[\'"]?',
        processors=[
            lambda items: [item for item in items if item != 'final'],
            lambda items: '.'.join(items),
        ],
    )        